require("util")
require("defines")

global.pumpset = {}


function OnEntityBuild(entity)
    if entity.type == 'mining-drill' then -- pumpjacks have entity.type='mining-drill'
        local other_ents = entity.surface.find_entities{entity.position, entity.position}

        local on_spring = false
        for _, other in pairs(other_ents) do
            if other.name == 'sulfuric-acid' then
                on_spring = true
                break
            end
        end

        if not on_spring then return end

        -- it's a pumpjack and it's on a hot spring, therefore we need to track it.
        table.insert(global.pumpset, entity)
    end
end

function OnEntityRemove(entity)
    if entity.type == 'mining-drill' then -- pumpjacks have entity.type='mining-drill'
        for i,v in pairs(global.pumpset) do
            if v == entity then
                table.remove(global.pumpset,i)
                break
            end
        end
    end
end

--    ACTIVATED

--    Placed
script.on_event(defines.events.on_built_entity, function(event)
      OnEntityBuild(event.created_entity)
end)
--    Robot Placed
script.on_event(defines.events.on_robot_built_entity, function(event)
      OnEntityBuild(event.created_entity)
end)
--    Re-activated after deconstruction plan removal
script.on_event(defines.events.on_canceled_deconstruction, function(event)
      OnEntityBuild(event.entity)
end)

-- DEACTIVATED

--    Dead
script.on_event(defines.events.on_entity_died, function(event)
    OnEntityRemove(event.entity)
end)
--    Player Mined
script.on_event(defines.events.on_preplayer_mined_item, function(event)
    OnEntityRemove(event.entity)
end)
--    Marked for deconstruction
script.on_event(defines.events.on_marked_for_deconstruction, function(event)
     OnEntityRemove(event.entity)
end)

-- Tick

 script.on_event(defines.events.on_tick, function(event)
    if (global.pumpset ~= nil) then
        for index, entity in pairs(global.pumpset) do
            local fluidBox = entity.fluidbox[1]
            if fluidBox ~= nil and fluidBox.amount > 0 and fluidBox.type == "sulfuric-acid" and fluidBox.temperature < 100 then
                fluidBox.temperature = 100
                entity.fluidbox[1] = fluidBox
            end
        end
    end
end)
